@@ -1,30 +1,22 @@
-#
-# $Id: Check.pm,v 0.1 2001/03/31 10:54:01 ram Exp $
+package CGI::Test::Form::Widget::Box::Check;
+use strict;
+##################################################################
+# $Id: Check.pm,v 1.2 2003/09/29 11:00:38 mshiltonj Exp $
+# $Name: cgi-test_0-104_t1 $
+##################################################################
 #
 #  Copyright (c) 2001, Raphael Manfredi
-#  
+#
 #  You may redistribute only under the terms of the Artistic License,
 #  as specified in the README file that comes with the distribution.
 #
-# HISTORY
-# $Log: Check.pm,v $
-# Revision 0.1  2001/03/31 10:54:01  ram
-# Baseline for first Alpha release.
-#
-# $EndLog$
-#
-
-use strict;
-
-package CGI::Test::Form::Widget::Box::Check;
 
 #
 # This class models a FORM checkbox button.
 #
 
-require CGI::Test::Form::Widget::Box;
-use vars qw(@ISA);
-@ISA = qw(CGI::Test::Form::Widget::Box);
+use CGI::Test::Form::Widget::Box;
+use base qw(CGI::Test::Form::Widget::Box);
 
 use Carp::Datum;
 use Log::Agent;
@@ -33,13 +25,19 @@ use Log::Agent;
 # Attribute access
 #
 
-sub gui_type	{ "checkbox" }
+sub gui_type
+{
+    return "checkbox";
+}
 
 #
 # Defined predicates
 #
 
-sub is_radio	{ 0 }
+sub is_radio
+{
+    return 0;
+}
 
 1;
 
@@ -68,9 +66,24 @@ at will by users.
 The interface is the same as the one described
 in L<CGI::Test::Form::Widget::Box>.
 
-=head1 AUTHOR
+=head1 WEBSITE
 
-Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>
+You can find information about CGI::Test and other related modules at:
+
+   http://cgi-test.sourceforge.net
+
+=head1 PUBLIC CVS SERVER
+
+CGI::Test now has a publicly accessible CVS server provided by
+SourceForge (www.sourceforge.net).  You can access it by going to:
+
+    http://sourceforge.net/cvs/?group_id=89570
+
+=head1 AUTHORS
+
+The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+
+Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
 
 =head1 SEE ALSO
 
